
/*============================================================================*/
/* SR}hwvɋʂ郁bZ[W̊Ǘ                                 */
/*============================================================================*/

/*-a*/
#define C_FNMT "Vږ"
#define C_FNMC "Vɒǉ鍀ڂ̖Ow肷"

/*-A*/
#define C_NEWT "VڂƂďo"
#define C_NEWC "̃IvVɂAw肵ڂûł͂ȂAVɍڂǉ"

/*-u*/
#define C_NOFT "svf[^o̓t@C"
#define C_NOFC "w̏ɈvȂso͂t@C"

/*-q*/
#define C_SEQT "V[PV"
#define C_SEQC "-kŎw肵ڂPʂɏ̂ł͂ȂA̓f[^̃R[hɏ]ďs"

/*-i*/
#define C_INFT "̓t@C"
#define C_INFC "̓t@Cw肷Bt@C̃TtBbNX.gzłΎIɉ𓀂ȂB܂̃p[^ȗꂽɂ͕W͂B"

/*-o*/
#define C_OTFT "o̓t@C"
#define C_OTFC "o̓t@Cw肷Bt@C̃TtBbNX.gzłΎIɈkďo͂B܂̃p[^ȗꂽɂ͕Wo͂ɏo͂B"

/*-z*/
#define C_ZIPT "Wo͂̈k"
#define C_ZIPC "o̓t@C̎wȗƂÃtOݒ肷ƁAWo͂Ɉkďo͂B"

/*-t*/
#define C_TXTT "plain text"
#define C_TXTC "o̓f[^̍\ƂāAXMLtablef[^\łȂplain textgB"

/*-T*/
#define C_TMPT "ƃfBNg"
#define C_TMPC "\[gȂǂňꎞIɗpt@Ci[fBNgB"

/*author*/
#define C_HELPA "Yukinobu Hamuro,Naoki Katoh"

/*bugreport*/
#define C_HELPB "musashi-users@lists.sourceforge.jp"

/*homepage*/
#define C_HELPH "http://musashi.sourceforge.jp"
